@@ -1,5 +1,7 @@
 """
-Main interface for dlm service literal definitions.
+Type annotations for dlm service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/literals.html)
 
 Usage::
 
